<template>
    <div class="loan-info-box">
        <x-header slot="header"
                  style="width:100%;height:46px;background-color: #ec6758"
                  title="照片审核"
                  :left-options="{backText: '', preventGoBack:true}"
                  @on-click-back="goBackPage"
        ></x-header>
        <flow class="progressState">
            <flow-state state="1" title="填写资料" class="currentStep porcolor"></flow-state>
            <flow-line is-done></flow-line>
            <flow-state state="2" title="绑定银行卡" class="currentStep porcolor"></flow-state>
            <flow-line is-done></flow-line>
            <flow-state state="3" title="照片上传" class="currentStep porcolor"></flow-state>
            <flow-line></flow-line>
            <flow-state state="4" title="三方授权"></flow-state>
            <flow-line></flow-line>
            <flow-state state="5" title="提交申请"></flow-state>
        </flow>
        <div v-if="resultCode===2">
            <div class="success_okandno">
                <div>
                    <i class="iconfont icon-iconfontdengdai"></i>
                </div>
                <h2>等待处理</h2>
            </div>
            <div class="bindingSuccee">
                <p>
                    照片上传中，预计时间2分钟，您可点击“刷新”查询绑定结果
                </p>
            </div>
            <div style="height: 20px"></div>
            <box gap="0 15px">
                <x-button type="primary" @click.native="Refresh">刷新</x-button>
            </box>
            <div style="height: 20px"></div>
        </div>
        <div v-if="resultCode===1">
            <div class="success_okandno">
                <div>
                    <i class="iconfont icon-roundcheckfill-copy"></i>
                </div>
                <h2>上传成功</h2>
            </div>
            <div class="bindingSuccee">
                <p>
                    您的影像资料已上传成功，请点击 “下一步”
                    进行芝麻授权
                </p>
            </div>
            <div style="height: 20px"></div>
            <box gap="0 15px">
                <x-button type="primary" @click.native="handleNextStep">下一步</x-button>
            </box>
            <div style="height: 20px"></div>
        </div>
        <div v-if="resultCode===0">
            <div class="success_okandno">
                <div>
                    <i class="iconfont icon-roundclosefill"></i>
                </div>
                <h2>上传失败</h2>
            </div>
            <div class="bindingSuccee">
                <p>
                    您的影像资料上传失败，请点击 “重新上传”
                    进行重新上传影像资料
                </p>
            </div>
            <div style="height: 20px"></div>
            <box gap="0 15px">
                <x-button type="primary" @click.native="gobackId">重新上传</x-button>
            </box>
            <div style="height: 20px"></div>
        </div>
    </div>
</template>

<script>
    import {
        Flow,
        FlowState,
        FlowLine,
        XHeader,
        Group,
        GroupTitle,
        Cell,
        XInput,
        Selector,
        XButton,
        Box,
        Actionsheet,
        Msg
    } from 'vux';
    import FSpace from '../../../components/common/FSpace.vue';
    import validate from '../../../tool/validator';
    import SysApi from '../../../api/api'
    import statusCodeManage from '../../../api/statusCodeManage'

    export default {
        name: 'pictureUp',
        data() {
            return {
                personalInfo: {
                    relMobile2: null,
                    relMobile: null
                }, // 初始化的用户信息
                isLastStep: false, // 是否是最后一步
                activePageItem: 0, // 激活当前页
                pageList: [], // 一共有几页

                resultCode: 2,
            };
        },

        methods: {
            //初始化状态
            initPie() {
                let _this = this;
                let prodId = {
                    prodId: this.$route.query.prodId,
                    resultType: 2,
                };
                SysApi.result(prodId).then(
                    res => {
                        console.log(res);
                        _this.resultCode = res.body.resultCode;
                    }, error => {
                        statusCodeManage.showTipOfStatusCode(error)
                    }
                )
            },

            //刷新
            Refresh() {
                this.initPie();
            },
            //授权成功下一步路由
            handleNextStep() {
                //prodId: this.$route.query.prodId,
                this.$router.push({path: '/bnd/credit/sesame', query: {prodId: this.$route.query.prodId}});
            },
            //重新上传
            gobackId() {
                this.$router.push({path: '/bnd/credit/idPicture', query: {prodId: this.$route.query.prodId}})
            },

            //返回上一页
            goBackPage() {
                // 如果是第一步的话，那么返回到上一个页面
                if (this.activePageItem <= 1) {
                    this.$router.back();
                    // 不是的话，那么显示上一步
                } else {
                    this.activePageItem--;
                    this.isLastStep = this.pageList.length === this.activePageItem;
                }
            },
            // 得到选项列表统一的方法
            getOptionsList(optionList) {
                let tmpList = [];
                if (optionList instanceof Array) {
                    optionList.forEach(function (item) {
                        tmpList.push({
                            key: item.code,
                            value: item.name
                        });
                    });
                }
                return tmpList;
            },

        },
        activated: function () {
            this.initPie();
        },
        components: {
            Group,
            GroupTitle,
            Cell,
            XInput,
            Selector,
            XHeader,
            XButton,
            Box,
            Flow,
            FlowState,
            FlowLine,
            Actionsheet,
            FSpace,
            Msg
        }
    };
</script>

<style lang="less">
    @import "../../../style/mixin.less";

    .loan-info-box {
        background-color: @color-background-default;
        .vux-header {
            .color-linear-gradient(@color-primary-light, @color-primary, 90deg);
            .vux-header-left {
                .left-arrow:before {
                    border: solid 1px @color-white;
                    border-width: 2px 0 0 2px;
                }
            }
        }
        .progressState div p {
            font-size: @font-size-tiny;
        }
        .weui-wepay-flow__state {
            width: 16px;
            height: 16px;
            top: -1px;
            padding-top: 1px;
        }
        .currentStep .weui-wepay-flow__state {
            width: 16px;
            height: 16px;
            padding-top: 1px;
            border: 1px solid @color-primary;
            color: @color-primary;
            border-radius: 50%;
            background-color: @color-white;
        }
        .weui-input {
            height: 28px;
            line-height: 28px;
        }
        .weui-wepay-flow, .weui-wepay-flow-auto {
            padding: 10px 40px 30px;
            background: @color-white;
        }
        .weui-wepay-flow__li_done .weui-wepay-flow__state,
        .weui-wepay-flow__process {
            background-color: @color-primary;
        }
    }

    .weui-wepay-flow {
        background-color: @color-white;
    }

    .left-arrow:before {
        border-color: @color-white;
    }

    .weui-cells__title {
        margin: 0 !important;
        font-size: 16PX !important;
    }

    .weui-input, .weui-cell__bd {
        font-size: @font-size-base;
    }

    .weui-label {
        font-size: @font-size-base;
    }

    .personInfo ::-webkit-input-placeholder { /* WebKit browsers */
        color: #bfbfbf;
    }

    .personInfo :-moz-placeholder { /* Mozilla Firefox 4 to 18 */
        color: #bfbfbf;
    }

    .personInfo ::-moz-placeholder { /* Mozilla Firefox 19+ */
        color: #bfbfbf;
    }

    .personInfo :-ms-input-placeholder { /* Internet Explorer 10+ */
        color: #bfbfbf;
    }

    .header-space {
        height: 46px;
    }

    .loan-info-box .weui-cell_select .weui-select {
        padding-right: 2.5rem;
        direction: rtl;
    }

    .loan-info-box .weui-btn_primary {
        .color-linear-gradient(@color-primary-light, @color-primary, 90deg);
    }

    .loan-info-box .weui-btn_primary:not(.weui-btn_disabled):active {
        color: rgba(255, 255, 255, 0.6);
        background-color: rgb(241, 95, 79);;
    }

    /*------------------------------*/
    .Code_ls {
        padding: 0.25rem 1.25rem;
        h4 {
            padding-bottom: 2rem;
            padding-top: 1rem;
            font-size: 1.2rem;
            font-weight: normal;
            color: @color-text-primary;
        }
        span {
            color: @color-text-third;
            display: inline-block;
        }
        span:last-child {
            margin-left: 0.5rem;
        }
    }

    .vux-no-group-title {
        margin-top: 0.77rem !important;
    }

    .loan-info-box .currentStep .weui-wepay-flow__state {
        background-color: @color-primary;
        color: @color-white !important;
        line-height: 1rem;
    }

    .weui-wepay-flow__li.weui-wepay-flow__li .weui-wepay-flow__state {
        width: 1.33333rem;
        height: 1.33333rem;
        border-radius: 1.58333rem;
        color: @color-text-third;
        line-height: 1.33333rem;
    }

    .loan-info-box .weui-wepay-flow, .loan-info-box .weui-wepay-flow-auto {
        padding: 0.83333rem 2.33333rem 2.5rem;
    }

    .loan-info-box .weui-input {
        text-align: left;
    }

    .porcolor p {
        color: @color-primary;
    }

    .weui-btn weui-btn_mini weui-btn_primary {
        background-color: @color-white !important;
    }

    .weui-msg__icon-area i {
        color: @color-primary !important;
    }

    .bindingSuccee {
        text-align: center;
        p {
            text-align: center;
            color: @color-text-third;
            font-size: @font-size-medium;
            width: 25rem;
            margin: 0 auto;

        }

    }

    .weui-msg__icon-area {
        margin-bottom: -1.2rem !important;
    }

    .success_okandno {
        width: 6.5rem;
        margin: 0 auto;
        padding: 3rem 0;
        img {
            width: 100%;
        }
        h2 {
            font-weight: normal;
            font-size: @font-size-primary;
            text-align: center;
        }
    }

    .success_okandno {
        div {
            text-align: center;
            height: 8rem;
        }
    }

    .iconfont {
        font-size: 6rem;
        color: #0092f1;
    }

    .icon-roundclosefill {
        color: #ff4d53 !important;
    }

    .loan-info-box .weui-wepay-flow, .loan-info-box .weui-wepay-flow-auto {
        padding: 0.83333rem 2.33333rem 2.5rem;
    }

    .weui-btn:after {
        border: none !important;
    }

    .weui-btn {
        font-size: @font-size-primary !important;
    }
</style>
